zeitsprung package
==================

Submodules
----------

zeitsprung.base module
----------------------

.. automodule:: zeitsprung.base
   :members:
   :undoc-members:
   :show-inheritance:

zeitsprung.database module
--------------------------

.. automodule:: zeitsprung.database
   :members:
   :undoc-members:
   :show-inheritance:

zeitsprung.scraping module
--------------------------

.. automodule:: zeitsprung.scraping
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: zeitsprung
   :members:
   :undoc-members:
   :show-inheritance:
